aioseinfeld
===========

v0.2.0
------

Feature release

- Implemented seinfeld.passage()
- Requires Python 3.7+

```
$ git shortlog -s v0.1.0...v0.2.0
     4	John Reese
```


v0.1.0
------

Initial release\n\n

```
$ git shortlog -s c4428d3f2f3e90ad144c6675e0b03dfb25e3e31b...v0.1.0
     1	John Reese
```

